package model

import (
	"context"
	"gorm.io/gorm"
	"yx-dataset-server/app/errors"
	"yx-dataset-server/app/model/entity"
	"yx-dataset-server/app/schema"
)

// NewLoginHistory 创建LoginHistory存储实例
func NewLoginHistory(db *gorm.DB) *LoginHistory {
	return &LoginHistory{db}
}

// LoginHistory LoginHistory存储
type LoginHistory struct {
	db *gorm.DB
}

func (a *LoginHistory) getQueryOption(opts ...schema.LoginHistoryQueryOptions) schema.LoginHistoryQueryOptions {
	var opt schema.LoginHistoryQueryOptions
	if len(opts) > 0 {
		opt = opts[0]
	}
	return opt
}

// Query 查询数据
func (a *LoginHistory) Query(ctx context.Context, params schema.LoginHistoryQueryParam, opts ...schema.LoginHistoryQueryOptions) (*schema.LoginHistoryQueryResult, error) {
	db := entity.GetLoginHistoryDB(ctx, a.db)
	if v := params.Code; v != "" {
		db = db.Where("code=?", v)
	}
	if v := params.LikeCode; v != "" {
		db = db.Where("code LIKE ?", "%"+v+"%")
	}
	if v := params.LikeName; v != "" {
		db = db.Where("name LIKE ?", "%"+v+"%")
	}
	if v := params.Status; v > 0 {
		db = db.Where("status=?", v)
	}
	if v := params.RecordIDs; len(v) > 0 {
		db = db.Where("record_id in (?)", v)
	}
	db = db.Order("id DESC")

	opt := a.getQueryOption(opts...)
	var list entity.LoginHistorys
	pr, err := WrapPageQuery(ctx, db, opt.PageParam, &list)
	if err != nil {
		return nil, errors.ErrDBServerInternalError
	}
	qr := &schema.LoginHistoryQueryResult{
		PageResult: pr,
		Data:       list.ToSchemaLoginHistorys(),
	}

	return qr, nil
}

// Get 查询指定数据
func (a *LoginHistory) Get(ctx context.Context, recordID string, opts ...schema.LoginHistoryQueryOptions) (*schema.LoginHistory, error) {
	db := entity.GetLoginHistoryDB(ctx, a.db).Where("record_id=?", recordID)
	var item entity.LoginHistory
	ok, err := FindOne(ctx, db, &item)
	if err != nil {
		return nil, errors.ErrDBServerInternalError
	} else if !ok {
		return nil, nil
	}

	return item.ToSchemaLoginHistory(), nil
}

// Create 创建数据
func (a *LoginHistory) Create(ctx context.Context, item schema.LoginHistory) error {
	LoginHistory := entity.SchemaLoginHistory(item).ToLoginHistory()
	result := entity.GetLoginHistoryDB(ctx, a.db).Create(LoginHistory)
	if err := result.Error; err != nil {
		return errors.ErrDBServerInternalError
	}
	return nil
}

// Update 更新数据
func (a *LoginHistory) Update(ctx context.Context, recordID string, item schema.LoginHistory) error {
	LoginHistory := entity.SchemaLoginHistory(item).ToLoginHistory()
	result := entity.GetLoginHistoryDB(ctx, a.db).Where("record_id=?", recordID).Omit("record_id", "creator").Updates(LoginHistory)
	if err := result.Error; err != nil {
		return errors.ErrDBServerInternalError
	}
	return nil
}

// Delete 删除数据
func (a *LoginHistory) Delete(ctx context.Context, recordID string) error {
	result := entity.GetLoginHistoryDB(ctx, a.db).Where("record_id=?", recordID).Delete(entity.LoginHistory{})
	if err := result.Error; err != nil {
		return errors.ErrDBServerInternalError
	}
	return nil
}

// UpdateStatus 更新状态
func (a *LoginHistory) UpdateStatus(ctx context.Context, recordID string, status int) error {
	result := entity.GetLoginHistoryDB(ctx, a.db).Where("record_id=?", recordID).Update("status", status)
	if err := result.Error; err != nil {
		return errors.ErrDBServerInternalError
	}
	return nil
}
